```
usage: xdtransform [-h] [-s SOURCE] [-d DESTINATION] -t TRANSFORM

optional arguments:
  -h, --help            show this help message and exit
  -s SOURCE, --source SOURCE
                        The source XML file (you can specify - to mean stdin)
  -d DESTINATION, --destination DESTINATION
                        The destination XML file (you can specify - to mean stdout)
  -t TRANSFORM, --transform TRANSFORM
                        The transformation XML file
```